tuplettools.Tuplet
==================

.. abjad-lineage:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet

.. autoclass:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.append
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.extend
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.force_fraction
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.from_duration_and_ratio
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.from_leaf_and_ratio
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.from_nonreduced_ratio_and_nonreduced_fraction
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.implied_prolation
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.index
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.insert
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_augmentation
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_diminution
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_invisible
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_simultaneous
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_trivial
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.lilypond_format
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.multiplied_duration
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.multiplier
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.override
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.pop
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.preferred_denominator
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.remove
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.reverse
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.select
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.select_leaves
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.select_notes_and_chords
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.set
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.set_minimum_denominator
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.storage_format
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.to_fixed_duration_tuplet
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.toggle_prolation
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__contains__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__copy__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__delitem__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__eq__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__getitem__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__len__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__mul__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__ne__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__repr__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__rmul__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__setitem__
      ~abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__str__

Bases
-----

- :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

- :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.implied_prolation
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_augmentation
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_diminution
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_trivial
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.multiplied_duration
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.override
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.set
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.force_fraction
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_invisible
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_simultaneous
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.multiplier
   :noindex:

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.preferred_denominator
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.append
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.extend
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.index
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.insert
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.pop
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.remove
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.reverse
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.select
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.select_leaves
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.select_notes_and_chords
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.set_minimum_denominator
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.to_fixed_duration_tuplet
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.toggle_prolation
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.from_duration_and_ratio
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.from_leaf_and_ratio
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.from_nonreduced_ratio_and_nonreduced_fraction
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__contains__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__copy__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__delitem__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__eq__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__getitem__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__len__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__mul__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__ne__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__repr__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__rmul__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__setitem__
   :noindex:

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__str__
   :noindex:
